// Copyright Sebastian Wiesner <sebastian@swsnr.de>
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0.If a copy of the MPL was not distributed with this
// file, You can obtain one at https://mozilla.org/MPL/2.0/.
//
// Alternatively, the contents of this file may be used under the terms
// of the GNU General Public License Version 2 or later, as described below:
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
import { EventEmitter } from "resource:///org/gnome/shell/misc/signals.js";
import sources from "../sources/all.js";

export class NoSuchSource extends Error {
    key;

    constructor(key, opts) {
        super(`No source with ${key} exists`, opts);
        this.key = key;
    }
}

const findSourceByKey = (key) => {
    const source = sources.find((s) => s.metadata.key === key);
    if (source) {
        return source;
    }
    else {
        throw new NoSuchSource(key);
    }
};

export class SourceSelector extends EventEmitter {
    _selectedSource;

    constructor(source) {
        super();
        this._selectedSource = source;
    }

    static forKey(key) {
        return new SourceSelector(findSourceByKey(key));
    }

    selectSource(key) {
        if (this._selectedSource.metadata.key !== key) {
            this._selectedSource = findSourceByKey(key);
            this.emit("source-changed", this._selectedSource);
        }
    }

    get selectedSource() {
        return this._selectedSource;
    }

    destroy() {
        this.disconnectAll();
    }
}
